# AutoMLx

Library to interpretable models!

## Installation
Run the following to install:

```python
pip install automlx
```

## Usage

```python
from hellowortd import say _ hello
# Generate "Hello, World!
say_hello()
# Generate "Hello, Everybody!
say_hello("Everybody")
```